@@ -2,7 +2,7 @@ package Net::DNS::RR::AFSDB;
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: AFSDB.pm 1945 2023-11-22 08:02:31Z willem $)[2];
+our $VERSION = (qw$Id: AFSDB.pm 2002 2025-01-07 09:57:46Z willem $)[2];
 
 use base qw(Net::DNS::RR);
 
@@ -71,8 +71,8 @@ __END__
 
 =head1 SYNOPSIS
 
-    use Net::DNS;
-    $rr = Net::DNS::RR->new('name AFSDB subtype hostname');
+	use Net::DNS;
+	$rr = Net::DNS::RR->new('name AFSDB subtype hostname');
 
 =head1 DESCRIPTION
 
@@ -90,16 +90,16 @@ other unpredictable behaviour.
 
 =head2 subtype
 
-    $subtype = $rr->subtype;
-    $rr->subtype( $subtype );
+	$subtype = $rr->subtype;
+	$rr->subtype( $subtype );
 
 A 16 bit integer which indicates the service offered by the
 listed host.
 
 =head2 hostname
 
-    $hostname = $rr->hostname;
-    $rr->hostname( $hostname );
+	$hostname = $rr->hostname;
+	$rr->hostname( $hostname );
 
 The hostname field is a domain name of a host that has a server
 for the cell named by the owner name of the RR.
@@ -138,7 +138,7 @@ DEALINGS IN THE SOFTWARE.
 =head1 SEE ALSO
 
 L<perl> L<Net::DNS> L<Net::DNS::RR>
-L<RFC1183(1)|https://tools.ietf.org/html/rfc1183>
-L<RFC5864|https://tools.ietf.org/html/rfc5864>
+L<RFC1183(1)|https://iana.org/go/rfc1183#section-1>
+L<RFC5864|https://iana.org/go/rfc5864>
 
 =cut
